==> hdb-0.00.tar.gz: hdb-0.00/hdbapp_master.c <==
/* hdbapp_master.c
** ezcdb master application
** wcm, 2010.05.30 - 2010.11.09
** ===
*/

/* std C: */
#include <stdlib.h>

/* lasagna: */
#include "cstr.h"
#include "nextopt.h"

/* hdbapp: */
#include "hdbapp.h"


/* globals: */
const char    *progname = NULL;
const char    *usage_prog =
    "[-hV] <cross|dump|dupes|get|grep|keys|make|match|merge|purge|stats> [opts...] [args...]";

const char    *progmode = NULL;
/* usage_mode is setup in specific module: */
const char    *usage_mode = NULL;


int main(int argc, char *argv[])
{
   nextopt_t      nopt = nextopt_INIT(argc, argv, ":hV");
   char           opt;
   char          *mode;
   int            e = 0;

   progname = nextopt_progname(&nopt);
   while ((opt = nextopt(&nopt))) {
      char           optc[2] = { nopt.opt_got, '\0' };
      switch (opt) {
      case 'h':
         usage();
         die(0);
         break;
      case 'V':
         version();
         die(0);
         break;
      case ':':
         fatal_usage("missing argument for option -", optc);
         break;
      case '?':
         if (nopt.opt_got != '?') {
            fatal_usage("invalid option -", optc);
         }
         /* else fallthrough: */
      default:
         die_usage();
         break;
      }
   }

   argc -= nopt.arg_ndx;
   argv += nopt.arg_ndx;

   if ((argc < 1) || (argv[0] == NULL) || (*argv[0] == '\0')) {
      fatal_usage("missing mode argument");
   }

   mode = argv[0];

   /* branch to mode/module: */
   if (cstr_cmp(mode, "cross") == 0) {
      progmode = "cross";
      e = hdbapp_cross(argc, argv);
   } else if (cstr_cmp(mode, "dump") == 0) {
      progmode = "dump";
      e = hdbapp_dump(argc, argv);
   } else if (cstr_cmp(mode, "dupes") == 0) {
      progmode = "dupes";
      e = hdbapp_dupes(argc, argv);
   } else if (cstr_cmp(mode, "get") == 0) {
      progmode = "get";
      e = hdbapp_get(argc, argv);
   } else if (cstr_cmp(mode, "grep") == 0) {
      progmode = "grep";
      e = hdbapp_grep(argc, argv);
   } else if (cstr_cmp(mode, "keys") == 0) {
      progmode = "keys";
      e = hdbapp_keys(argc, argv);
   } else if (cstr_cmp(mode, "make") == 0) {
      progmode = "make";
      e = hdbapp_make(argc, argv);
   } else if (cstr_cmp(mode, "match") == 0) {
      progmode = "match";
      e = hdbapp_match(argc, argv);
   } else if (cstr_cmp(mode, "merge") == 0) {
      progmode = "merge";
      e = hdbapp_merge(argc, argv);
   } else if (cstr_cmp(mode, "purge") == 0) {
      progmode = "purge";
      e = hdbapp_purge(argc, argv);
   } else if (cstr_cmp(mode, "stats") == 0) {
      progmode = "stats";
      e = hdbapp_stats(argc, argv);
   } else {
      fatal_usage("unknown mode argument: ", mode);
   }

   return e;
}


/* eof (hdbapp_master.c) */

==> hdb-0.01.tar.gz: hdb-0.01/hdbapp_master.c <==
/* hdbapp_master.c
** ezcdb master application
** wcm, 2010.05.30 - 2010.12.16
** ===
*/

/* std C: */
#include <stdlib.h>

/* lasagna: */
#include "cstr.h"
#include "nextopt.h"

/* hdbapp: */
#include "hdbapp.h"


/* globals: */
const char    *progname = NULL;
const char    *usage_prog =
    "[-hV] <about|cross|dump|dupes|get|grep|keys|make|match|merge|purge|stats> [opts...] [args...]";

const char    *progmode = NULL;
/* usage_mode is setup in specific module: */
const char    *usage_mode = NULL;


int main(int argc, char *argv[])
{
   nextopt_t      nopt = nextopt_INIT(argc, argv, ":hV");
   char           opt;
   char          *mode;
   int            e = 0;

   progname = nextopt_progname(&nopt);
   while ((opt = nextopt(&nopt))) {
      char           optc[2] = { nopt.opt_got, '\0' };
      switch (opt) {
      case 'h':
         usage();
         die(0);
         break;
      case 'V':
         version();
         die(0);
         break;
      case ':':
         fatal_usage("missing argument for option -", optc);
         break;
      case '?':
         if (nopt.opt_got != '?') {
            fatal_usage("invalid option -", optc);
         }
         /* else fallthrough: */
      default:
         die_usage();
         break;
      }
   }

   argc -= nopt.arg_ndx;
   argv += nopt.arg_ndx;

   if ((argc < 1) || (argv[0] == NULL) || (*argv[0] == '\0')) {
      fatal_usage("missing mode argument");
   }

   mode = argv[0];

   /* branch to mode/module: */
   if (cstr_cmp(mode, "about") == 0) {
      progmode = "about";
      e = hdbapp_about(argc, argv);
   } else if (cstr_cmp(mode, "cross") == 0) {
      progmode = "cross";
      e = hdbapp_cross(argc, argv);
   } else if (cstr_cmp(mode, "dump") == 0) {
      progmode = "dump";
      e = hdbapp_dump(argc, argv);
   } else if (cstr_cmp(mode, "dupes") == 0) {
      progmode = "dupes";
      e = hdbapp_dupes(argc, argv);
   } else if (cstr_cmp(mode, "get") == 0) {
      progmode = "get";
      e = hdbapp_get(argc, argv);
   } else if (cstr_cmp(mode, "grep") == 0) {
      progmode = "grep";
      e = hdbapp_grep(argc, argv);
   } else if (cstr_cmp(mode, "keys") == 0) {
      progmode = "keys";
      e = hdbapp_keys(argc, argv);
   } else if (cstr_cmp(mode, "make") == 0) {
      progmode = "make";
      e = hdbapp_make(argc, argv);
   } else if (cstr_cmp(mode, "match") == 0) {
      progmode = "match";
      e = hdbapp_match(argc, argv);
   } else if (cstr_cmp(mode, "merge") == 0) {
      progmode = "merge";
      e = hdbapp_merge(argc, argv);
   } else if (cstr_cmp(mode, "purge") == 0) {
      progmode = "purge";
      e = hdbapp_purge(argc, argv);
   } else if (cstr_cmp(mode, "stats") == 0) {
      progmode = "stats";
      e = hdbapp_stats(argc, argv);
   } else {
      fatal_usage("unknown mode argument: ", mode);
   }

   return e;
}


/* eof (hdbapp_master.c) */
